@@ -1,7 +1,7 @@
 import re
 from typing import Pattern, Callable
 
-from atcodertools.codegen.code_generators import cpp, java, rust, python, nim, d, cs, swift, go
+from atcodertools.codegen.code_generators import cpp, java, rust, python, nim, d, cs, swift, go, julia
 from atcodertools.codegen.models.code_gen_args import CodeGenArgs
 from atcodertools.tools.templates import get_default_template_path
 from atcodertools.codegen.code_style_config import INDENT_TYPE_TAB
@@ -194,6 +194,17 @@ GO = Language(
     exec_filename="{filename}{exec_extension}"
 )
 
+JULIA = Language(
+    name="julia",
+    display_name="Julia",
+    extension="jl",
+    submission_lang_pattern=re.compile(".*Julia.*"),
+    default_code_generator=julia.main,
+    default_template_path=get_default_template_path('jl'),
+    compile_command="",
+    test_command="julia {filename}.jl",
+    exec_filename="{filename}.jl"
+)
 
-ALL_LANGUAGES = [CPP, JAVA, RUST, PYTHON, NIM, DLANG, CSHARP, SWIFT, GO]
+ALL_LANGUAGES = [CPP, JAVA, RUST, PYTHON, NIM, DLANG, CSHARP, SWIFT, GO, JULIA]
 ALL_LANGUAGE_NAMES = [lang.display_name for lang in ALL_LANGUAGES]
